package com.example.union_ad_ssgf.load

import android.app.Activity
import android.content.Intent
import android.util.Log
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.example.union_ad_ssgf.config.UnionADConfig
import com.example.union_ad_ssgf.event.AdEventAction
import com.example.union_ad_ssgf.page.BaseAdPage
import com.qq.e.ads.nativ.ADSize
import com.qq.e.ads.nativ.NativeExpressAD
import com.qq.e.ads.nativ.NativeExpressADView
import com.qq.e.comm.util.AdError
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import java.util.Locale

/** 信息流加载对象 */
class FeedAdLoad : BaseAdPage(), NativeExpressAD.NativeExpressADListener {
    private val TAG = FeedAdLoad::class.java.getSimpleName()
    private var result: MethodChannel.Result? = null

    /**
     * 加载信息流广告列表
     * @param call
     * @param result
     */
    fun loadFeedAdList(activity: Activity?, call: MethodCall, result: MethodChannel.Result) {
        this.result = result
        showAd(activity, null, call)
    }

    override fun onNoAD(error: AdError) {
        val msg =
            String.format(
                Locale.getDefault(),
                "onError, error code: %d, error msg: %s",
                error.getErrorCode(),
                error.getErrorMsg()
            )
        Log.i(TAG, "onError, adError=$msg")
        sendErrorEvent(error.getErrorCode(), error.getErrorMsg())
        this.result!!.success(ArrayList<Int>())
    }

    override fun onADLoaded(list: MutableList<NativeExpressADView>) {
        Log.i(TAG, "onADLoaded")
        val adResultList: MutableList<Int> = ArrayList()

        if (list.isEmpty()) {
            result!!.success(adResultList)
            return
        }
        for (adItem in list) {
            val key = adItem.hashCode()
            adResultList.add(key)
            FeedAdManager.getInstance()?.putAd(key, adItem)
        }
        // 添加广告事件
        sendEvent(AdEventAction.onAdLoaded)
        result!!.success(adResultList)
    }

    override fun onRenderFail(nativeExpressADView: NativeExpressADView) {
        Log.i(TAG, "onRenderFail")
        sendErrorEvent(-100, "onRenderFail")
        sendBroadcastEvent(nativeExpressADView, AdEventAction.onAdError)
    }

    private fun sendBroadcastEvent(adView: NativeExpressADView, event: String) {
        val intent = Intent()
        intent.setAction(UnionADConfig.KEY_FEED_VIEW + "_" + adView.hashCode())
        intent.putExtra("event", event)
        LocalBroadcastManager.getInstance(activity!!).sendBroadcast(intent)
    }

    override fun onRenderSuccess(nativeExpressADView: NativeExpressADView) {
        Log.i(TAG, "onRenderSuccess")
        sendEvent(AdEventAction.onAdPresent)
        sendBroadcastEvent(nativeExpressADView, AdEventAction.onAdPresent)
    }

    override fun onADExposure(nativeExpressADView: NativeExpressADView?) {
        Log.i(TAG, "onADExposure")
        sendEvent(AdEventAction.onAdExposure)
    }

    override fun onADClicked(nativeExpressADView: NativeExpressADView?) {
        Log.i(TAG, "onADClicked")
        sendEvent(AdEventAction.onAdClicked)
    }

    override fun onADClosed(nativeExpressADView: NativeExpressADView) {
        Log.i(TAG, "onADClosed")
        sendEvent(AdEventAction.onAdClosed)
        sendBroadcastEvent(nativeExpressADView, AdEventAction.onAdClosed)
    }

    override fun onADLeftApplication(p0: NativeExpressADView?) {}

    override fun loadAd(call: MethodCall?) {
        // 获取请求模板广告素材的尺寸
        val width: Int = call!!.argument("width")!!
        val height: Int = call.argument("height")!!
        val count: Int = call.argument("count")!!
        val ad = NativeExpressAD(activity, ADSize(width, height), posId, this)
        ad.loadAD(count)
    }
}
